\name{cld}

\title{cld}

\description{
  This is a wrapper function for the C code that performs a composite linkage 
  disequlibrum calculation. 
} 


\usage{
  cld(data, width = 5)
}

\arguments{
  \item{data}{Matrix of snp data organized as subjects by snps. Values should
   consist of 1 (homozygous major), 2 (heterozygous) or 
   3 (homozygous minor). Missing values are represented by 0.}
  \item{width}{Integer value indicating the number of neighboring snps 
   to be used in the linkage disequlibrium calculation.}
}

\details{
  Composite linkage disequilibrium is a statistical measure of association across 
  loci, when haplotype phase is not known. See Weir and Cockerham, 1989; 
  Weir 1996 pp. 94, 125. 

  Delta = n / N - 2 p_{A_1} p_{B_1}

   where
 
   N: number of individuals
   p_{A_1}: frequency of allele A_1 at snp A
   p_{B_1}: frequency of an allele B_1 at snp B
   n: 2 X_{A_1A_1, B_1B_1} + X_{A_1A_1, B_1B_2} +
       X_{A_1A_2, B_1B_1} + (1/2) X_{A_1A_2, B_1B_2}

  The number of linkage disequilibrium 
  comparisions made are (\# of snps - width)*width and therefore 
  the number of snps returned is (\# of snps - width). In the matrix
  of values returend, each row represents a snp and each column is a 
  single linkage disequilibrium comparision between that snp and one of its
  neighbors. The number of snp-snp comparisions is defined by the \code{width}
  argument. 

}

\value{
  A matrix of linkage disequilibrium values where the rows are snps and columns are
  the positions of neighboring snps the length of the \code{width} argument. 
  The number of snps returned is (\# of snps - width). 
}

\author{Student Name}

\references{
   WEIR, B., 1996 Genetic Data Analysis II. Sinauer Associates,
   Sunderland, MA.

   WEIR, B. S., and C. C. COCKERHAM, 1989 Complete characterization of
   disequilibrium at two loci, pp. 86–110 in Mathematical Evolutionary
   Theory, edited by M. W. FELDMAN. Princeton University Press,
   Princeton, NJ.
}

\seealso{
  \link{GWASdata-class} for the GWASdata class.
}

\examples{
#  library(ncdf)
#  file <- system.file("extdata","small_snpData.nc",package="StudentGWAS")
#  cols <- getNcdfVarSummary(file)$dim2
#  snps <- getColGWAS(file, first=1, last=cols) 
#  head(snps)
#  snpCLD <- .cld(snps)
#  dim(snpCLD)
#  head(snpCLD)
}

